=========
Easy File
=========


.. image:: https://pyup.io/repos/github/ruslan-rv-ua/easy_file/python-3-shield.svg
     :target: https://pyup.io/repos/github/ruslan-rv-ua/easy_file/
     :alt: Python 3

.. image:: https://img.shields.io/pypi/v/easy_file.svg
        :target: https://pypi.python.org/pypi/easy_file

.. image:: https://img.shields.io/travis/ruslan-rv-ua/easy_file.svg
        :target: https://travis-ci.com/ruslan-rv-ua/easy_file

.. image:: https://readthedocs.org/projects/easy-file/badge/?version=latest
        :target: https://easy-file.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Files for Humans


* Free software: MIT license
* Documentation: https://easy-file.readthedocs.io.


Features
--------

* based on `pathlib.Path`
* UTF-8 by default
* fast JSON serialization/deserialization with orjson_
* YAML serialization/deserialization 

Install
-------

* pip Install easy-file

Quickstart
----------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _orjson: https://github.com/ijl/orjson
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
